#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include <Adafruit_AHTX0.h>

#define SCREEN_WIDTH 128 // OLED display width, in pixels
#define SCREEN_HEIGHT 32 // OLED display height, in pixels
#define OLED_RESET     -1 // Reset pin # (or -1 if sharing Arduino reset pin)

#define peltierPin 15
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);
Adafruit_AHTX0 aht;

const float humidityThreshold = 45;


void setup() {
  Serial.begin(115200);
  aht.begin();
  display.begin(SSD1306_SWITCHCAPVCC, 0x3C);
  display.clearDisplay();
  display.setTextSize(2);
  display.setTextColor(WHITE);
  display.setRotation(2);
  display.display();
  pinMode(peltierPin,OUTPUT);
}

void loop() {
  display.clearDisplay();
  display.setCursor(0, 0);
  sensors_event_t humidity, temp;
  aht.getEvent(&humidity, &temp);// populate temp and humidity objects with fresh data
  float h = humidity.relative_humidity;
  display.print(h,1);
  display.println("%");
  float t = temp.temperature;
  display.print(t,1);
  display.println(" C");
  display.display();
  if(h>humidityThreshold){
    digitalWrite(peltierPin,HIGH);
  } else {
    digitalWrite(peltierPin,LOW);
  }
  delay(1000);
}
